package pl.alx.kurs.bazydanych;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.content.UriMatcher;
import android.database.Cursor;
import android.net.Uri;

public class OsobyProvider extends ContentProvider {

	private OsobyHelper helper;
	
	private static final int NIC_NIE_PASUJE = 0;
	private static final int WSZYSTKIE_OSOBY = 1;
	private static final int WYBRANA_OSOBA = 2;
	private static UriMatcher matcher = new UriMatcher(NIC_NIE_PASUJE);
	static {
		matcher.addURI("pl.alx.kurs.bazydanych.provider", "osoby", WSZYSTKIE_OSOBY);
		matcher.addURI("pl.alx.kurs.bazydanych.provider", "osoba/#", WYBRANA_OSOBA);
	}
	
	@Override
	public boolean onCreate() {
		helper = OsobyHelper.getInstance(getContext());
		return true;
	}

	@Override
	public Cursor query(Uri uri, String[] projection, String selection, String[] selectionArgs, String sortOrder) {
		Cursor kursor;
		switch (matcher.match(uri)) {
		case WSZYSTKIE_OSOBY:
			kursor = helper.getReadableDatabase().query("osoby", projection, selection, selectionArgs, null, null, sortOrder);
			break;
		case WYBRANA_OSOBA:
			kursor = helper.getReadableDatabase().query("osoby", projection, "_id=" + Integer.parseInt(uri.getLastPathSegment()), selectionArgs, null, null, sortOrder);
			break;
		default:
			throw new IllegalArgumentException("Unsupported URI: " + uri);
		}
		kursor.setNotificationUri(getContext().getContentResolver(), Uri.parse("content://pl.alx.kurs.bazydanych.provider/osoby"));
		return kursor;
	}

	@Override
	public String getType(Uri uri) {
		switch (matcher.match(uri)) {
		case WSZYSTKIE_OSOBY:
			return "vnd.android.cursor.dir/vnd.pl.alx.kurs.bazydanych.osoby";
		case WYBRANA_OSOBA:
			return "vnd.android.cursor.item/vnd.pl.alx.kurs.bazydanych.osoby";
		default:
			throw new IllegalArgumentException("Unsupported URI: " + uri);
		}
	}

	@Override
	public Uri insert(Uri uri, ContentValues values) {
		long id = helper.getWritableDatabase().insert("osoby", "imie", values);
		getContext().getContentResolver().notifyChange(Uri.parse("content://pl.alx.kurs.bazydanych.provider/osoby"), null);
		return Uri.parse("content://pl.alx.kurs.bazydanych.provider/osoba/" + id);
	}

	@Override
	public int delete(Uri uri, String selection, String[] selectionArgs) {
		// TODO Auto-generated method stub
		return 0;
	}

	@Override
	public int update(Uri uri, ContentValues values, String selection,
			String[] selectionArgs) {
		// TODO Auto-generated method stub
		return 0;
	}

}
